@@ -56,16 +56,6 @@ if [ ! -e ${AXYL_HOME}/lucene ] ; then
   exit 1
 fi
 
-function sub_vars () {
-  A=`find $1 -type f -exec grep -l "$2" {} \;`
-  if [ "$A" != "" ]; then
-    for F in $A; do
-      sed -e "s;$2;$3;g" $F > $$.tmp && mv $$.tmp $F
-    done
-    rm -f $$.tmp
-  fi
-}
-
 # Makes the Axyl Lucene data area. If the area already exists then
 # existing index and log data will be preserved, but the configuration
 # files will be re-asserted. The intent is to establish correctness..
