@@ -154,22 +154,6 @@ public class Config
     return 9;
   }
 
-  /**
-   * Remove unicode escape sequences.
-   */
-
-  private String unicode(String data)
-  {
-    if (data == null)
-      return null;
-
-    boolean modified = false;
-
-    StringBuffer sb = new StringBuffer();
-    int length = data.length();
-    return null;
-  }
-
   /**
    * Destructive cleansing of data.  Uses data as intermediate
    * storage, overwriting its contents.
@@ -256,6 +240,7 @@ public class Config
     return data.toString();
   }
 
+  /*
   private void put(String key, String value, int line)
   {
     Line entry = new Line(line, key, value);
@@ -266,7 +251,8 @@ public class Config
   {
 
   }
-
+  */
+  
   private static class Line
   {
     // Line number of the entry
